from urllib.request import urlretrieve
import matplotlib.pyplot as plt
from astropy.io import fits
import numpy as np
import matplotlib.patches as patches
import os
import sys


def progress_print(*args):
    print("{0}/{1}".format(((args[0] + 1)*args[1]), args[2]), end='\r')


def download(file_name, url="http://solis.nso.edu/pubkeep/vsm_current_m630l_hr.fits.gz"):
    urlretrieve(url, file_name, reporthook=progress_print)


file_name = "output.fts"

if os.path.exists(file_name):
  result = input("File already exists. Download new?(yes/no)")
  if result[0] not in ['y', 'n']:
    print("Wrong answer!")
    sys.exit(1)
  if result[0] == 'y':
    download(file_name)
else:
  download(file_name)

f = fits.open(file_name)

array = f[0].data[0][::-1, :]

mx = array.max()
mn = array.min()

mx_row, mx_column = np.where(array == mx)

mx_region = array[mx_row - 100:mx_row + 100, mx_column - 100:mx_column + 100]

plt.figure(1, figsize=(10, 5))
plt.suptitle(f[0].header['DATE'])
ax = plt.subplot2grid((2, 2), (0, 0), rowspan=2)
plt.title("Full map")
array[np.where(array == 0)] = np.nan
plt.imshow(array, cmap='gray', clim=[mn * 0.8, mx * 0.8])
ax.add_patch(patches.Rectangle((mx_column - 100, mx_row - 100), 200, 200, fill=False))
plt.colorbar()
plt.subplot2grid((2, 2), (0, 1))
plt.title("Region")
plt.imshow(mx_region, cmap='gray', clim =np.array([-1, 1]) * np.max([np.abs(np.min(mx_region)),np.abs(np.max(mx_region))]))
plt.colorbar()
plt.subplot2grid((2, 2), (1, 1))
plt.title("Slice")
plt.plot(mx_region[100, :], color='red', label='hslice')
plt.plot(mx_region[:, 100], color='blue', label='vslice')
plt.legend()
plt.tight_layout()
plt.savefig("output.png")
plt.show()
f.close()
